@@ -1,6 +1,8 @@
-import attr
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
 
-from marshmallow_annotations.ext.attrs import AttrsSchema
+import attr
+from marshmallow3_annotations.ext.attrs import AttrsSchema
 
 
 @attr.s(auto_attribs=True, kw_only=True)
@@ -10,6 +12,9 @@ class Tag:
     def __init__(self, tag_name: str):
         self.tag_name = tag_name
 
+    def __str__(self) -> str:
+        return self.tag_name
+
 
 class TagSchema(AttrsSchema):
     class Meta:
