@@ -1,6 +1,11 @@
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
+
 import logging
 from re import sub
-from typing import Any, List, Dict, Tuple, Optional
+from typing import (
+    Any, Dict, List, Optional, Tuple,
+)
 
 from atlasclient.client import Atlas
 from atlasclient.exceptions import BadRequest
@@ -9,10 +14,10 @@ from atlasclient.models import Entity, EntityCollection
 from atlasclient.utils import parse_table_qualified_name
 
 from search_service.models.dashboard import SearchDashboardResult
-from search_service.models.table import SearchTableResult
-from search_service.models.search_result import SearchResult
-from search_service.models.table import Table
+from search_service.models.feature import SearchFeatureResult
+from search_service.models.table import SearchTableResult, Table
 from search_service.models.tag import Tag
+from search_service.models.user import SearchUserResult
 from search_service.proxy import BaseProxy
 from search_service.proxy.statsd_utilities import timer_with_counter
 
@@ -89,7 +94,8 @@ class AtlasProxy(BaseProxy):
 
             badges: List[Tag] = tags
 
-            table = Table(name=entity_name,
+            table = Table(id=f"{entity.typeName}://{db_cluster}.{db_name}/{entity_name}",
+                          name=entity_name,
                           key=f"{entity.typeName}://{db_cluster}.{db_name}/{entity_name}",
                           description=entity_attrs.get('description'),
                           cluster=db_cluster,
@@ -266,7 +272,19 @@ class AtlasProxy(BaseProxy):
     def fetch_user_search_results(self, *,
                                   query_term: str,
                                   page_index: int = 0,
-                                  index: str = '') -> SearchResult:
+                                  index: str = '') -> SearchUserResult:
+        pass
+
+    def fetch_dashboard_search_results(self, *,
+                                       query_term: str,
+                                       page_index: int = 0,
+                                       index: str = '') -> SearchDashboardResult:
+        pass
+
+    def fetch_feature_search_results(self, *,
+                                     query_term: str,
+                                     page_index: int = 0,
+                                     index: str = '') -> SearchFeatureResult:
         pass
 
     def update_document(self, *, data: List[Dict[str, Any]], index: str = '') -> str:
@@ -277,9 +295,3 @@ class AtlasProxy(BaseProxy):
 
     def delete_document(self, *, data: List[str], index: str = '') -> str:
         raise NotImplementedError()
-
-    def fetch_dashboard_search_results(self, *,
-                                       query_term: str,
-                                       page_index: int = 0,
-                                       index: str = '') -> SearchDashboardResult:
-        pass
